@@ -11,7 +11,7 @@ class MinStack(object):
     def push(self, val: int) -> None:
         self.stack.append(val)
 
-        if not self.minstack or val <= self.getMin():
+        if not self.minstack or val <= self.get_min():
             self.minstack.append(val)
 
     def pop(self) -> None:
